@@ -2,7 +2,7 @@ PS1='$ '
 TOMCAT_DST_FOLDER="tomcat"
 TOMCAT_VERSION="7.0.61"
 TOMCAT_PID_FILENAME="tomcat.pid"
-SMARTGEAR_DISTRIBUTION_DIRECTORY="smartgears-distribution-1.2.1-SNAPSHOT"
+SMARTGEAR_DISTRIBUTION_DIRECTORY="smartgears-distribution-1.2.2-3.7.0"
 SMARTGEAR_ROOT=${PWD}
 
 BUNDLE_HOME=${SMARTGEAR_ROOT}
